package com.sogou.speech.butterfly;

import android.os.Environment;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import com.sohu.inputmethod.sogou.leakanalysis.BuildConfig;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.lang.ref.WeakReference;
/* compiled from: SogouSource */
/* loaded from: classes.dex */
public class ButterflyEngine {
    public static final String TAG = "offlinevoice>>" + ButterflyEngine.class.getSimpleName();
    public static final String VOICE_FAILED = "voice_failed";
    public static boolean isDecoderDestroyed = false;
    public static ButterflyEngine mBF = null;
    public static boolean mDecoderCanceled = false;
    public static boolean mDecoderStoped = false;
    public static final int mDefaultMaxTime = 30000;
    public static final int mDefaultVADBeginThreshold = 3000;
    public static final int mDefaultVADEndThreshold = 1000;
    public static boolean mRecordingStop = false;
    public static final String mVersion = "100";
    public boolean hasOnResult = true;
    public boolean hasOnSpeechEnd = true;
    public boolean mBatchTesting;
    public String mButterflyDir;
    public Cx mButterflyListener;
    public BFDecoderHandler mDecoderHandler;
    public boolean mError;
    public boolean mInited;
    public String mResultPath;
    public boolean mSaveData;
    public boolean mSpeechEnded;
    public boolean mTestWav;
    public String mUtterance;
    public BFVolumeHandler mVolumeHandler;
    public String mWavDir;
    public String modelFilePath;

    /* JADX INFO: Access modifiers changed from: private */
    /* compiled from: SogouSource */
    /* loaded from: classes.dex */
    public static class BFDecoderHandler extends Handler {
        public WeakReference<ButterflyEngine> mBF;

        public BFDecoderHandler(Looper looper, ButterflyEngine butterflyEngine) {
            super(looper);
            this.mBF = new WeakReference<>(butterflyEngine);
        }

        @Override // android.os.Handler
        public void handleMessage(Message message) {
            super.handleMessage(message);
            this.mBF.get().handleDecoderMessage(message);
        }
    }

    /* compiled from: SogouSource */
    /* loaded from: classes.dex */
    private static class BFDecoderMessage {
        public static final int BFDECODER_MSG_BATCH_END = 6;
        public static final int BFDECODER_MSG_BATCH_NEXT = 5;
        public static final int BFDECODER_MSG_ERR = -1;
        public static final int BFDECODER_MSG_INIT = 0;
        public static final int BFDECODER_MSG_ON_START = 1;
        public static final int BFDECODER_MSG_QUIT = 7;
        public static final int BFDECODER_MSG_RECV_DATA = 4;
        public static final int BFDECODER_MSG_START_DECODE = 2;
        public static final int BFDECODER_MSG_STOP_DECODE = 3;
    }

    /* compiled from: SogouSource */
    /* loaded from: classes.dex */
    private class BFDecoderThread implements Runnable {
        public BFDecoderThread() {
        }

        @Override // java.lang.Runnable
        public void run() {
            Looper.prepare();
            ButterflyEngine.this.mDecoderHandler = new BFDecoderHandler(Looper.myLooper(), ButterflyEngine.this);
            ButterflyEngine.this.mDecoderHandler.obtainMessage(0).sendToTarget();
            Looper.loop();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* compiled from: SogouSource */
    /* loaded from: classes.dex */
    public static class BFVolumeHandler extends Handler {
        public WeakReference<ButterflyEngine> mBF;

        public BFVolumeHandler(Looper looper, ButterflyEngine butterflyEngine) {
            super(looper);
            this.mBF = new WeakReference<>(butterflyEngine);
        }

        @Override // android.os.Handler
        public void handleMessage(Message message) {
            super.handleMessage(message);
            this.mBF.get().handleVolumeMessage(message);
        }
    }

    /* compiled from: SogouSource */
    /* loaded from: classes.dex */
    private static class BFVolumeMessage {
        public static final int BFVOLUME_MSG_QUIT = 1;
        public static final int BFVOLUME_MSG_UPDATE = 0;
    }

    /* compiled from: SogouSource */
    /* loaded from: classes.dex */
    private class BFVolumnThread implements Runnable {
        public BFVolumnThread() {
        }

        @Override // java.lang.Runnable
        public void run() {
            Looper.prepare();
            ButterflyEngine.this.mVolumeHandler = new BFVolumeHandler(Looper.myLooper(), ButterflyEngine.this);
            Looper.loop();
        }
    }

    public ButterflyEngine(String str) {
        this.modelFilePath = str;
    }

    private void batchEnd() {
        if (this.mBatchTesting) {
            Cx cx = this.mButterflyListener;
            if (cx != null) {
                cx.b();
            }
            this.mBatchTesting = false;
        }
    }

    private void clear() {
        if (this.mTestWav) {
            setSaveData(this.mSaveData);
            this.mTestWav = false;
        }
    }

    private boolean createDebugDir() {
        String externalStorageState = Environment.getExternalStorageState();
        if (!externalStorageState.equals("mounted")) {
            C0760qA.a(TAG, "Can not access SD card.");
            return false;
        } else if (externalStorageState.equals("mounted_ro")) {
            C0760qA.a(TAG, "Can not write to SD card.");
            return false;
        } else {
            this.mButterflyDir = Environment.getExternalStorageDirectory() + "/SogouSpeech/ButterflyEngine/";
            File file = new File(this.mButterflyDir);
            if (!file.exists()) {
                if (!file.mkdirs()) {
                    String str = TAG;
                    C0760qA.a(str, "Failed to mkdirs" + this.mButterflyDir);
                    this.mButterflyDir = null;
                    return false;
                }
            } else if (!file.isDirectory()) {
                String str2 = TAG;
                C0760qA.a(str2, "debug dir[" + this.mButterflyDir + "] exists but not is directory, delete");
                file.delete();
                if (!file.mkdirs()) {
                    String str3 = TAG;
                    C0760qA.a(str3, "Failed to mkdirs" + this.mButterflyDir);
                    this.mButterflyDir = null;
                    return false;
                }
            }
            this.mWavDir = this.mButterflyDir + "wavs/";
            File file2 = new File(this.mWavDir);
            if (!file2.exists()) {
                if (!file2.mkdirs()) {
                    String str4 = TAG;
                    C0760qA.a(str4, "Failed to mkdirs" + this.mButterflyDir);
                    this.mWavDir = null;
                    return false;
                }
            } else if (!file2.isDirectory()) {
                String str5 = TAG;
                C0760qA.a(str5, "debug WAV dir[" + this.mWavDir + "] exists but not a directory, delete");
                file2.delete();
                if (!file2.mkdirs()) {
                    String str6 = TAG;
                    C0760qA.a(str6, "Failed to mkdirs" + this.mWavDir);
                    this.mWavDir = null;
                    return false;
                }
            }
            this.mResultPath = this.mButterflyDir + "result.txt";
            File file3 = new File(this.mResultPath);
            if (file3.exists()) {
                return true;
            }
            try {
                file3.createNewFile();
                return true;
            } catch (IOException e) {
                String str7 = TAG;
                C0760qA.a(str7, "Failed to create file: " + this.mResultPath);
                this.mResultPath = null;
                e.printStackTrace();
                return false;
            }
        }
    }

    public static synchronized void destroyButterfly() {
        synchronized (ButterflyEngine.class) {
            String str = TAG;
            Ur.a(str, "destroyButterfly(),mBF==" + mBF);
            if (isDecoderDestroyed) {
                Ur.b(TAG, "has been destroyed");
                return;
            }
            if (mBF != null) {
                if (mBF.mDecoderHandler != null) {
                    mBF.mDecoderHandler.obtainMessage(7).sendToTarget();
                }
                if (mBF.mVolumeHandler != null) {
                    mBF.mVolumeHandler.obtainMessage(1).sendToTarget();
                }
            }
            mBF = null;
            BFASRJNIInterface.destroyDecoder();
            mDecoderStoped = true;
            isDecoderDestroyed = true;
            mRecordingStop = true;
        }
    }

    private void error(String str) {
        this.mError = true;
        Message obtainMessage = this.mDecoderHandler.obtainMessage(-1);
        obtainMessage.obj = str;
        obtainMessage.sendToTarget();
        stop();
    }

    public static ButterflyEngine getButterflyInstance(String str) {
        if (mBF == null) {
            synchronized (ButterflyEngine.class) {
                if (mBF == null) {
                    mBF = new ButterflyEngine(str);
                }
            }
        }
        return mBF;
    }

    public static String getVersion() {
        return mVersion;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void handleDecoderMessage(Message message) {
        int i = message.what;
        if (i == -1) {
            Cx cx = this.mButterflyListener;
            if (cx != null) {
                String str = (String) message.obj;
                int i2 = message.arg1;
                if (cx != null) {
                    cx.a(i2, str, BuildConfig.FLAVOR);
                }
            }
        } else if (i == 0) {
            if (!initButterfly()) {
                Ur.b(TAG, "Failed to initButterfly.");
                error("初始化错误");
                return;
            }
            this.mInited = true;
            mDecoderStoped = true;
            Cx cx2 = this.mButterflyListener;
            if (cx2 != null) {
                cx2.a();
            }
        } else if (i == 1) {
            Cx cx3 = this.mButterflyListener;
        } else if (i == 2) {
            startDecode();
        } else if (i == 3) {
            Ur.a(TAG, "receive BFDecoderMessage.BFDECODER_MSG_STOP_DECODE");
            stopDecode();
        } else if (i == 4) {
            receiveData(message);
        } else if (i == 6) {
            batchEnd();
        } else if (i != 7) {
        } else {
            Looper.myLooper().quit();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void handleVolumeMessage(Message message) {
        int i = message.what;
        if (i == 0) {
            Cx cx = this.mButterflyListener;
        } else if (i != 1) {
        } else {
            Looper.myLooper().quit();
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:61:0x00db A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private boolean initButterfly() {
        FileInputStream fileInputStream;
        IOException e;
        FileNotFoundException e2;
        Ur.a(TAG, "ButterflyEngine.initButterfly()");
        BFASRJNIInterface.setMaxTimeInMilliSec(mDefaultMaxTime);
        FileInputStream fileInputStream2 = null;
        try {
            try {
                fileInputStream = new FileInputStream(new File(this.modelFilePath));
                try {
                    if (BFASRJNIInterface.initDecoder(fileInputStream.getFD(), 0L) < 0) {
                        Ur.b(TAG, "--> initButterfly Failed to loadModel");
                        Ur.b(TAG, "--> initButterfly finally\u3000close file input stream!!!");
                        try {
                            fileInputStream.close();
                        } catch (IOException e3) {
                            e3.printStackTrace();
                        }
                        return false;
                    }
                    Ur.b(TAG, "--> initButterfly finally\u3000close file input stream!!!");
                    try {
                        fileInputStream.close();
                    } catch (IOException e4) {
                        e4.printStackTrace();
                    }
                    BFASRJNIInterface.setCallbackObject(this);
                    BFASRJNIInterface.setCallbackMethodOnSpeechEnd("onSpeechEnd");
                    BFASRJNIInterface.setCallbackMethodOnResult("onResult");
                    BFASRJNIInterface.setVadEnabled(true);
                    BFASRJNIInterface.setAutoStopEnabled(true);
                    BFASRJNIInterface.setVadThreshold(mDefaultVADBeginThreshold, mDefaultVADEndThreshold);
                    BFASRJNIInterface.setCommaEnabled(true);
                    Ur.a(TAG, "++++ initButterfly load model success!");
                    isDecoderDestroyed = false;
                    return true;
                } catch (FileNotFoundException e5) {
                    e2 = e5;
                    Ur.b(TAG, "--> initButterfly speech model file NOT exist!!! " + e2.toString());
                    Ur.b(TAG, "--> initButterfly finally\u3000close file input stream!!!");
                    if (fileInputStream != null) {
                        try {
                            fileInputStream.close();
                        } catch (IOException e6) {
                            e6.printStackTrace();
                        }
                    }
                    return false;
                } catch (IOException e7) {
                    e = e7;
                    Ur.b(TAG, "--> initButterfly speech model loading IOException!!! " + e.toString());
                    Ur.b(TAG, "--> initButterfly finally\u3000close file input stream!!!");
                    if (fileInputStream != null) {
                        try {
                            fileInputStream.close();
                        } catch (IOException e8) {
                            e8.printStackTrace();
                        }
                    }
                    return false;
                }
            } catch (Throwable th) {
                th = th;
                Ur.b(TAG, "--> initButterfly finally\u3000close file input stream!!!");
                if (0 != 0) {
                    try {
                        fileInputStream2.close();
                    } catch (IOException e9) {
                        e9.printStackTrace();
                    }
                }
                throw th;
            }
        } catch (FileNotFoundException e10) {
            fileInputStream = null;
            e2 = e10;
        } catch (IOException e11) {
            fileInputStream = null;
            e = e11;
        } catch (Throwable th2) {
            th = th2;
            Ur.b(TAG, "--> initButterfly finally\u3000close file input stream!!!");
            if (0 != 0) {
            }
            throw th;
        }
    }

    private void receiveData(Message message) {
        synchronized (ButterflyEngine.class) {
            if (!this.mSpeechEnded && !this.mError && !mDecoderStoped) {
                boolean z = true;
                if (BFASRJNIInterface.setData((short[]) message.obj, message.arg1, message.arg2 != 0) < 0) {
                    String str = TAG;
                    StringBuilder sb = new StringBuilder();
                    sb.append("error in BFASRJNIInterface.setData, isLast:");
                    if (message.arg2 == 0) {
                        z = false;
                    }
                    sb.append(z);
                    Ur.b(str, sb.toString());
                    error("setData失败");
                }
            }
        }
    }

    private void startDecode() {
        Ur.a(TAG, "ButterflyEngine # startDecode()");
        if (!mDecoderStoped) {
            Ur.a(TAG, "ButterflyEngine # startDecode decoder has been started");
            return;
        }
        long currentTimeMillis = System.currentTimeMillis();
        if (this.mUtterance == null) {
            this.mUtterance = String.valueOf(currentTimeMillis);
        }
        if (BFASRJNIInterface.startDecode() < 0) {
            error("启动解码器失败");
            Ur.b(TAG, "ButterflyEngine # BFASRJNIInterface.startDecode() < 0");
        }
        this.mUtterance = null;
        mDecoderStoped = false;
        mDecoderCanceled = false;
    }

    private void stopDecode() {
        synchronized (ButterflyEngine.class) {
            Ur.a(TAG, "ButterflyEngine # stopDecode()");
            if (mDecoderStoped) {
                Ur.b(TAG, "ButterflyEngine # decoder has been stopped in stopDecode()");
                return;
            }
            mDecoderStoped = true;
            if (BFASRJNIInterface.stopDecode() < 0) {
                Ur.b(TAG, "ButterflyEngine # BFASRJNIInterface.stopDecode() < 0");
                error(Ky.a().m343a().m302a());
            }
            clear();
        }
    }

    private float updateVolume(short[] sArr, int i) {
        double d = 0.0d;
        for (int i2 = 0; i2 < i; i2++) {
            double abs = Math.abs((int) sArr[i2]);
            Double.isNaN(abs);
            d += abs;
        }
        double d2 = i;
        Double.isNaN(d2);
        return (float) (d / ((d2 * 32767.0d) * 0.05d));
    }

    public void cancel() {
        C0760qA.a(TAG, "ButterflyEngine # cancel()");
        if (!this.mInited) {
            C0760qA.a(TAG, "Not inited @cancel() ");
            return;
        }
        mDecoderCanceled = true;
        if (mRecordingStop) {
            return;
        }
        mRecordingStop = true;
        this.hasOnResult = false;
        this.hasOnSpeechEnd = false;
        this.mDecoderHandler.removeMessages(4);
        this.mDecoderHandler.obtainMessage(3).sendToTarget();
    }

    public void init(Hr hr, Cx cx) {
        if (hr == null) {
            throw new IllegalArgumentException("audioRecordListener==null");
        }
        if (cx != null) {
            this.mButterflyListener = cx;
            if (this.mInited) {
                Ur.b(TAG, "Already inited");
                return;
            }
            new Thread(new BFDecoderThread()).start();
            new Thread(new BFVolumnThread()).start();
            this.mSaveData = false;
            return;
        }
        throw new IllegalArgumentException("butterflyListener==null");
    }

    public boolean isInited() {
        return this.mInited;
    }

    public void onResult(String str, float f, int i) {
        boolean z = i == 1;
        String str2 = TAG;
        Ur.a(str2, "result: " + str + ", confidence: " + f + ", isLastTmp: " + i + ",isLast:" + z);
        if (this.mError || mDecoderCanceled) {
            return;
        }
        if (TextUtils.isEmpty(str)) {
            if (z) {
                this.mButterflyListener.a(1, Hy.a("voice_failed"), "no result");
            }
            Ur.b(TAG, "result is empty, skip ");
            return;
        }
        Cx cx = this.mButterflyListener;
        if (cx != null && this.hasOnResult) {
            cx.a(str, z);
        }
        if (this.hasOnResult) {
            return;
        }
        this.hasOnResult = true;
    }

    public void onSpeechEnd(int i) {
        String str = TAG;
        Ur.a(str, "onSpeechEnd,time:" + i);
        this.mSpeechEnded = true;
        Cx cx = this.mButterflyListener;
        if (cx != null && this.hasOnSpeechEnd) {
            cx.a(i);
        }
        if (!this.hasOnSpeechEnd) {
            this.hasOnSpeechEnd = true;
        }
        stop();
    }

    public void recognize(short[] sArr, int i) {
        this.mDecoderHandler.obtainMessage(4, i, 1, sArr).sendToTarget();
        this.mDecoderHandler.obtainMessage(3).sendToTarget();
    }

    public void setMaxTimeInMilliSec(int i) {
        BFASRJNIInterface.setMaxTimeInMilliSec(i);
    }

    public void setSaveData(boolean z) {
        this.mSaveData = z;
        if (this.mSaveData && createDebugDir()) {
            BFASRJNIInterface.setWAVDir(this.mWavDir);
        }
    }

    public void setVadThreshold(int i, int i2) {
        BFASRJNIInterface.setVadThreshold(i, i2);
    }

    public void start() {
        if (!this.mInited) {
            error("ButterflyEngine初始化错误");
            Ur.b(TAG, "ButterflyEngine初始化错误");
            return;
        }
        this.mDecoderHandler.obtainMessage(1).sendToTarget();
        this.mSpeechEnded = false;
        this.mError = false;
        mRecordingStop = false;
        this.mDecoderHandler.obtainMessage(2).sendToTarget();
    }

    public void stop() {
        Ur.a(TAG, "ButterflyEngine # stop()");
        if (!this.mInited) {
            Ur.b(TAG, "Not inited @stop() ");
        } else if (mRecordingStop) {
            Ur.b(TAG, "Has already been stopped before this stop");
        } else {
            mRecordingStop = true;
            BFVolumeHandler bFVolumeHandler = this.mVolumeHandler;
            if (bFVolumeHandler != null) {
                bFVolumeHandler.removeMessages(0);
            }
            BFDecoderHandler bFDecoderHandler = this.mDecoderHandler;
            if (bFDecoderHandler != null) {
                bFDecoderHandler.obtainMessage(3).sendToTarget();
            }
        }
    }

    public void receiveData(short[] sArr, int i, boolean z) {
        if (this.mSpeechEnded || this.mError) {
            return;
        }
        BFDecoderHandler bFDecoderHandler = this.mDecoderHandler;
        if (bFDecoderHandler != null) {
            bFDecoderHandler.obtainMessage(4, i, z ? 1 : 0, sArr).sendToTarget();
        }
        BFVolumeHandler bFVolumeHandler = this.mVolumeHandler;
        if (bFVolumeHandler != null) {
            bFVolumeHandler.obtainMessage(0, i, -1, sArr).sendToTarget();
        }
        if (z) {
            stop();
        }
    }
}
