package com.voice.recognizer;

import android.content.Context;
import android.media.AudioManager;
import android.util.Log;
import com.sogou.base.moduler.voice.BaseVoiceModuler;
import com.sogou.speech.entity.DeviceInfo;
import com.sogou.speech.entity.LongAsrResponse;
import com.sogou.speech.entity.ShortAsrCandidates;
import com.sogou.speech.entity.ShortAsrResponse;
import com.sogou.speech.framework.SogouAsrTranslateEngine;
import com.sogou.speech.listener.LongAsrListener;
import com.sogou.speech.listener.ShortAsrListener;
import defpackage.Sr;
import java.util.List;
/* compiled from: SogouSource */
/* loaded from: classes.dex */
public class SogouVoiceRecognizer extends BaseVoiceModuler implements ShortAsrListener, LongAsrListener, Ir, Hr {
    public static final int MAX_LONG_ASR_LENGTH = 120000;
    public static final int MAX_SHORT_ASR_LENGTH = 60000;
    public static final String TAG = "voice>>" + SogouVoiceRecognizer.class.getSimpleName();
    public AudioManager mAudioManager;
    public C0963w<LF<C0627mH>> mResultLiveData = new C0963w<>();
    public StringBuilder mLongAsrResult = new StringBuilder();
    public int asrTimeMode = 1;
    public int mOnlineAsrAccent = 0;
    public boolean mIsStartCandidate = false;
    public boolean mIsTranditional = false;
    public boolean mIsListening = false;
    public AudioManager.OnAudioFocusChangeListener onAudioFocusChangeListener = new Ux(this);
    public Context mContext = Dy.a();
    public SogouAsrTranslateEngine mSogouAsrTranslateEngine = new SogouAsrTranslateEngine.Builder(this.mContext, 1, 0).deviceInfo(new DeviceInfo(Ey.m193a(), Ey.c(), Ey.e(), Ey.d())).partnerType(Sr.a.Mainline).onlineAsrMode(this.asrTimeMode).onlineAsrAccent(this.mOnlineAsrAccent).maxRecordingTime(getMaxRecordingTime()).preprocessListener(this).audioRecordListener(this).shortAsrListener(this).isNeededTraditionalChinese(this.mIsTranditional).isNeededCandidateWords(this.mIsStartCandidate).isEnableAgc(true).build();

    public SogouVoiceRecognizer() {
        this.mAudioManager = null;
        this.mAudioManager = (AudioManager) this.mContext.getSystemService("audio");
    }

    /* JADX INFO: Access modifiers changed from: private */
    public int abandonAudioFocus() {
        AudioManager audioManager = this.mAudioManager;
        if (audioManager == null) {
            return -1;
        }
        return audioManager.abandonAudioFocus(this.onAudioFocusChangeListener);
    }

    private void onError(String str) {
        this.mResultLiveData.a((C0963w<LF<C0627mH>>) LF.a(str));
        stopAsr();
    }

    private int requireAudioFocus() {
        AudioManager audioManager = this.mAudioManager;
        if (audioManager == null) {
            return -1;
        }
        return audioManager.requestAudioFocus(this.onAudioFocusChangeListener, 3, 2);
    }

    @Override // com.sogou.base.moduler.voice.BaseVoiceModuler
    public void destory() {
    }

    public int getMaxRecordingTime() {
        return this.asrTimeMode == 1 ? MAX_SHORT_ASR_LENGTH : MAX_LONG_ASR_LENGTH;
    }

    @Override // defpackage.Ir
    public void onAgcEnabled(boolean z) {
        String str = TAG;
        Log.i(str, "onAgcEnabled,enable:" + z);
    }

    @Override // defpackage.Ir
    public void onAgcError(int i, String str, String str2) {
        onError("agc error: " + str);
        release();
    }

    @Override // defpackage.Hr
    public void onAudioDataReceived(short[] sArr) {
        if (this.mIsListening) {
            return;
        }
        this.mResultLiveData.a((C0963w<LF<C0627mH>>) LF.a());
        this.mIsListening = true;
    }

    @Override // defpackage.Hr
    public void onAudioRecordError(int i, String str, String str2) {
        Log.i(TAG, "onAudioRecordError");
        release();
    }

    @Override // defpackage.Hr
    public void onAudioRecordRelease() {
        Log.i(TAG, "onAudioRecordRelease");
    }

    @Override // defpackage.Hr
    public void onAudioRecordStart() {
        Log.i(TAG, "onAudioRecordStart");
        requireAudioFocus();
    }

    @Override // defpackage.Hr
    public void onAudioRecordStop() {
        abandonAudioFocus();
        Log.i(TAG, "onAudioRecordStop");
    }

    @Override // com.sogou.speech.listener.LongAsrListener
    public void onLongAsrEndWithoutResult() {
    }

    @Override // com.sogou.speech.listener.LongAsrListener
    public void onLongAsrError(int i, String str, String str2) {
        this.mResultLiveData.a((C0963w<LF<C0627mH>>) LF.a(str));
        stopAsr();
    }

    @Override // com.sogou.speech.listener.LongAsrListener
    public void onLongAsrPartialResult(String str, long j, long j2, int i) {
        String str2 = TAG;
        Log.i(str2, "onLongAsrPartialResult,text:" + str + " token:" + j + " sampleBegin:" + j2 + " partNo:" + i);
        C0627mH c0627mH = new C0627mH();
        c0627mH.a(str);
        this.mResultLiveData.a((C0963w<LF<C0627mH>>) LF.a(c0627mH));
    }

    @Override // com.sogou.speech.listener.LongAsrListener
    public void onLongAsrResult(String str, long j, long j2, long j3, List<LongAsrResponse> list, boolean z) {
        if (this.mLongAsrResult != null) {
            String str2 = TAG;
            Log.i(str2, "onLongAsrResult,text:" + str + " token:" + j + " sampleBegin:" + j2);
            this.mLongAsrResult.append(str);
            C0627mH c0627mH = new C0627mH();
            c0627mH.a(this.mLongAsrResult.toString());
            this.mResultLiveData.a((C0963w<LF<C0627mH>>) LF.a(c0627mH));
        }
    }

    @Override // com.sogou.speech.listener.LongAsrListener
    public void onLongAsrSilent() {
        Log.i(TAG, "onLongAsrSilent");
    }

    @Override // com.sogou.speech.listener.ShortAsrListener
    public void onShortAsrError(int i, String str, String str2) {
        onError(str);
        release();
    }

    @Override // com.sogou.speech.listener.ShortAsrListener
    public void onShortAsrResult(Object obj, boolean z) {
        if (z) {
            ShortAsrCandidates shortAsrCandidates = (ShortAsrCandidates) obj;
            int status = shortAsrCandidates.getStatus();
            C0627mH c0627mH = new C0627mH();
            c0627mH.a(status == 2);
            if (status == 2) {
                String str = TAG;
                Log.i(str, "onShortAsrResult last result: " + shortAsrCandidates.getContent());
                c0627mH.a(shortAsrCandidates.getContent());
                c0627mH.b(shortAsrCandidates.getDoutuData());
            } else if (status == 1) {
                String str2 = TAG;
                Log.i(str2, "onShortAsrResult media result: " + shortAsrCandidates.getContent());
                c0627mH.a(shortAsrCandidates.getContent());
            }
            this.mResultLiveData.a((C0963w<LF<C0627mH>>) LF.a(c0627mH));
            return;
        }
        ShortAsrResponse shortAsrResponse = (ShortAsrResponse) obj;
        List<String> content = shortAsrResponse.getContent();
        int status2 = shortAsrResponse.getStatus();
        C0627mH c0627mH2 = new C0627mH();
        c0627mH2.a(status2 == 2);
        if (status2 == 2) {
            if (content != null && content.size() > 0) {
                String str3 = TAG;
                Log.i(str3, "onShortAsrResult old reg last result: " + content.get(0));
                c0627mH2.a(content.get(0));
                c0627mH2.b(shortAsrResponse.getDouTuData());
            }
        } else if (status2 == 1 && content != null && content.size() > 0) {
            String str4 = TAG;
            Log.i(str4, "onShortAsrResult old reg media result: " + content.get(0));
            c0627mH2.a(content.get(0));
        }
        this.mResultLiveData.a((C0963w<LF<C0627mH>>) LF.a(c0627mH2));
    }

    public void onSpeexError(int i, String str, String str2) {
        onError("speex error: " + str);
        release();
    }

    @Override // defpackage.Ir
    public void onVadError(int i, String str, String str2) {
        onError("vad error: " + str);
        release();
    }

    @Override // defpackage.Ir
    public void onVadFirstDetected() {
    }

    @Override // defpackage.Hr
    public void onVoiceDecibelChanged(double d) {
    }

    @Override // com.sogou.base.moduler.voice.BaseVoiceModuler
    public void release() {
        if (this.mSogouAsrTranslateEngine != null) {
            Log.i(TAG, "release asr.");
            this.mSogouAsrTranslateEngine.releaseAsrTranslate();
        }
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    @Override // com.sogou.base.moduler.voice.BaseVoiceModuler
    public void setAccent(String str) {
        char c;
        int hashCode = str.hashCode();
        if (hashCode == 3241) {
            if (str.equals("en")) {
                c = 2;
            }
            c = 65535;
        } else if (hashCode == 3398) {
            if (str.equals("jp")) {
                c = 3;
            }
            c = 65535;
        } else if (hashCode != 3431) {
            switch (hashCode) {
                case 120581:
                    if (str.equals("zhs")) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                case 120582:
                    if (str.equals("zht")) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
        } else {
            if (str.equals("kr")) {
                c = 4;
            }
            c = 65535;
        }
        if (c == 0) {
            this.mOnlineAsrAccent = 0;
        } else if (c == 1) {
            this.mOnlineAsrAccent = 1;
        } else if (c == 2) {
            this.mOnlineAsrAccent = 2;
        } else if (c == 3) {
            this.mOnlineAsrAccent = 3;
        } else if (c != 4) {
        } else {
            this.mOnlineAsrAccent = 4;
        }
    }

    @Override // com.sogou.base.moduler.voice.BaseVoiceModuler
    public void setIsStartCandidate(boolean z) {
        this.mIsStartCandidate = z;
    }

    @Override // com.sogou.base.moduler.voice.BaseVoiceModuler
    public void setIsTranditional(boolean z) {
        this.mIsTranditional = z;
    }

    @Override // com.sogou.base.moduler.voice.BaseVoiceModuler
    public void setLongSentenceMode(boolean z) {
        if (z) {
            this.asrTimeMode = 2;
        } else {
            this.asrTimeMode = 1;
        }
    }

    @Override // com.sogou.base.moduler.voice.BaseVoiceModuler
    public void setOnlineMode(boolean z) {
    }

    @Override // com.sogou.base.moduler.voice.BaseVoiceModuler
    public C0963w<LF<C0627mH>> startAsr() {
        Log.i(TAG, "start asr.");
        this.mResultLiveData.a((C0963w<LF<C0627mH>>) LF.b());
        this.mSogouAsrTranslateEngine.startAsrTranslate();
        return this.mResultLiveData;
    }

    @Override // com.sogou.base.moduler.voice.BaseVoiceModuler
    public void stopAsr() {
        if (this.mSogouAsrTranslateEngine != null) {
            Log.i(TAG, "stop asr.");
            this.mSogouAsrTranslateEngine.stopAsrTranslate();
            this.mIsListening = false;
        }
    }
}
