package sogou.input.model;

import android.content.Context;
import android.text.TextUtils;
import android.view.inputmethod.EditorInfo;
import com.sogou.common.InputInterface;
import java.util.ArrayList;
import java.util.Iterator;
/* compiled from: SogouSource */
/* loaded from: classes.dex */
public class InputModelManager implements InputInterface {
    public static int INPUT_INVALID = -10000;
    public static int INPUT_MODE_NULL = -10000;
    public static final String TAG = "InputModelManager";
    public int mChInputType;
    public int mHwInputType;
    public int mLanguageId;
    public int mPreviousInputType;
    public C0732pH mSogouSymbol;
    public int mInputType = -2;
    public boolean mIsEnglishInCh = false;
    public C0522jH imeStatusInfo = new C0522jH();
    public XF composingInfo = new XF();
    public PF candidateInfo = new PF();
    public final C0244bH remoteMsgInfo = new C0244bH();
    public TF extraCloudInfo = new TF();
    public C1037yF expressionInfo = new C1037yF();
    public final C0697oH mVoiceResultInfo = new C0697oH();
    public C0348eH mEditorComposingInfo = new C0348eH();
    public IG localeResourceStatusInfo = new IG();
    public Context mAppContext = Dy.a();

    public InputModelManager() {
        int i = INPUT_INVALID;
        this.mChInputType = i;
        this.mHwInputType = i;
        this.mPreviousInputType = i;
        initIMEStatus();
    }

    private int getDefaultInputMode() {
        FG m310a = JF.a().m310a();
        JG m204a = m310a.m204a();
        if (m204a != null) {
            return GF.a(m310a.a().b(), m204a.b(), m204a.a());
        }
        return -1;
    }

    private int getInputMode(String str) {
        FG m310a = JF.a().m310a();
        JG a = m310a.a(this.mLanguageId, str);
        if (a != null) {
            return GF.a(m310a.a().b(), a.b(), a.a());
        }
        return -1;
    }

    private void initIMEStatus() {
        FG m310a = JF.a().m310a();
        this.mLanguageId = C0374ez.a(this.mAppContext.getResources().getString(C0409fz.module_input_mode), this.mAppContext.getResources().getString(C0409fz.language_id), INPUT_INVALID);
        if (this.mLanguageId == INPUT_INVALID) {
            this.mLanguageId = m310a.a().b();
            C0374ez.m1160a(this.mAppContext.getResources().getString(C0409fz.module_input_mode), this.mAppContext.getResources().getString(C0409fz.language_id), this.mLanguageId);
        }
        this.mInputType = C0374ez.a(this.mAppContext.getResources().getString(C0409fz.module_input_mode), this.mAppContext.getResources().getString(C0409fz.input_type), INPUT_INVALID);
        this.mChInputType = C0374ez.a(this.mAppContext.getResources().getString(C0409fz.module_input_mode), this.mAppContext.getResources().getString(C0409fz.ch_input_type), INPUT_INVALID);
        this.mHwInputType = C0374ez.a(this.mAppContext.getResources().getString(C0409fz.module_input_mode), this.mAppContext.getResources().getString(C0409fz.hw_input_type), INPUT_INVALID);
        if (this.mHwInputType == INPUT_INVALID) {
            this.mHwInputType = 5;
        }
        C0760qA.a(TAG, "mLanguageId+" + this.mLanguageId + " mInputType=" + this.mInputType + "mChInputType=" + this.mChInputType);
        int i = this.mChInputType;
        if (i == INPUT_INVALID) {
            switchInputType(C1072zG.a(C0756px.a().b(m310a.a(this.mLanguageId).c())));
        } else {
            this.mInputType = i;
        }
        loadIme(this.mInputType);
    }

    private void loadIme(int i) {
        int inputMode;
        String a = C1072zG.a(i);
        if (TextUtils.isEmpty(a) || (inputMode = getInputMode(a)) == INPUT_MODE_NULL) {
            return;
        }
        getIMEStatusInfo().a(new GF(GF.a(inputMode), GF.c(inputMode), GF.b(inputMode)));
    }

    private boolean needTrackEnStatusInCh() {
        EditorInfo m371a = Ly.a().m371a();
        return (m371a == null || C0262br.c(m371a) || C0262br.d(m371a) || C0262br.b(m371a)) ? false : true;
    }

    private void setChInputType(int i) {
        this.mChInputType = i;
        C0374ez.m1160a(this.mAppContext.getResources().getString(C0409fz.module_input_mode), this.mAppContext.getResources().getString(C0409fz.ch_input_type), this.mChInputType);
    }

    private void setHwInputType(int i) {
        this.mHwInputType = i;
        C0374ez.m1160a(this.mAppContext.getResources().getString(C0409fz.module_input_mode), this.mAppContext.getResources().getString(C0409fz.hw_input_type), this.mHwInputType);
    }

    @Override // com.sogou.common.InputInterface
    public PF getCandidateInfo() {
        return this.candidateInfo;
    }

    @Override // com.sogou.common.InputInterface
    public int getChInputType() {
        return this.mChInputType;
    }

    public IF getCurrentKeyboardBean() {
        GF a = getIMEStatusInfo().a();
        Iterator it = ((ArrayList) JF.a().m310a().m206a()).iterator();
        while (it.hasNext()) {
            DG dg = (DG) it.next();
            if (dg.b() == a.a()) {
                Iterator it2 = ((ArrayList) dg.m133b()).iterator();
                while (it2.hasNext()) {
                    JG jg = (JG) it2.next();
                    if (jg.b() == a.c() && jg.a() == a.b()) {
                        return jg.m311a();
                    }
                }
                continue;
            }
        }
        return null;
    }

    @Override // com.sogou.common.InputInterface
    public DG getCurrentLanguageBean() {
        GF a = getIMEStatusInfo().a();
        C0760qA.d(TAG, "getCurrentLanguageBean inputMode languageId:" + a.a());
        return getLanguageBeanByInputMode(a);
    }

    @Override // com.sogou.common.InputInterface
    public C0348eH getEditorComposingInfo() {
        return this.mEditorComposingInfo;
    }

    public C1037yF getExpressionInfo() {
        return this.expressionInfo;
    }

    @Override // com.sogou.common.InputInterface
    public TF getExtraCloudInfo() {
        return this.extraCloudInfo;
    }

    @Override // com.sogou.common.InputInterface
    public int getHwInputType() {
        return this.mHwInputType;
    }

    @Override // com.sogou.common.InputInterface
    public C0522jH getIMEStatusInfo() {
        return this.imeStatusInfo;
    }

    @Override // com.sogou.common.InputInterface
    public String getImeName(int i) {
        return C1072zG.a(i);
    }

    @Override // com.sogou.common.InputInterface
    public int getInputType() {
        return this.mInputType;
    }

    @Override // com.sogou.common.InputInterface
    public boolean getIsEnglishInCh() {
        return this.mIsEnglishInCh;
    }

    @Override // com.sogou.common.InputInterface
    public DG getLanguageBeanByInputMode(GF gf) {
        if (gf != null) {
            Iterator it = ((ArrayList) JF.a().m310a().m206a()).iterator();
            while (it.hasNext()) {
                DG dg = (DG) it.next();
                if (dg.b() == gf.a()) {
                    return dg;
                }
            }
            return null;
        }
        return null;
    }

    public DG getLanguageBeanByToken(String str) {
        Iterator it = ((ArrayList) JF.a().m310a().m206a()).iterator();
        while (it.hasNext()) {
            DG dg = (DG) it.next();
            if (TextUtils.equals(dg.d(), str)) {
                return dg;
            }
        }
        return null;
    }

    @Override // com.sogou.common.InputInterface
    public int getLanguageId() {
        return this.mLanguageId;
    }

    @Override // com.sogou.common.InputInterface
    public IG getLocaleResourceStatusInfo() {
        return this.localeResourceStatusInfo;
    }

    @Override // com.sogou.common.InputInterface
    public int getPreviousInputType() {
        return this.mPreviousInputType;
    }

    @Override // com.sogou.common.InputInterface
    public C0244bH getRemoteMsgInfo() {
        return this.remoteMsgInfo;
    }

    @Override // com.sogou.common.InputInterface
    public ArrayList<C0767qH> getSogouSymbol() {
        if (this.mSogouSymbol == null) {
            this.mSogouSymbol = new C0732pH();
            this.mSogouSymbol.m1442c();
        }
        return this.mSogouSymbol.a();
    }

    @Override // com.sogou.common.InputInterface
    public ArrayList<CharSequence> getUserSymbol() {
        if (this.mSogouSymbol == null) {
            this.mSogouSymbol = new C0732pH();
            this.mSogouSymbol.m1442c();
        }
        if (this.mInputType == -1) {
            return this.mSogouSymbol.c();
        }
        return this.mSogouSymbol.b();
    }

    @Override // com.sogou.common.InputInterface
    public C0697oH getVoiceResultInfo() {
        return this.mVoiceResultInfo;
    }

    @Override // com.sogou.common.InputInterface
    public void resetInputType() {
        this.mPreviousInputType = INPUT_INVALID;
    }

    @Override // com.sogou.common.InputInterface
    public void setInputType(int i) {
        int i2 = this.mInputType;
        if (i2 != i) {
            this.mPreviousInputType = i2;
            if (needTrackEnStatusInCh()) {
                if (C1072zG.m1734a(this.mInputType) && C1072zG.m1735b(i)) {
                    this.mIsEnglishInCh = true;
                } else if (C1072zG.m1735b(this.mInputType) && C1072zG.m1734a(i)) {
                    this.mIsEnglishInCh = false;
                }
            }
            if (C1072zG.m1734a(i)) {
                setChInputType(i);
            }
            if (C1072zG.c(i)) {
                setHwInputType(i);
            }
            this.mInputType = i;
            C0374ez.m1160a(this.mAppContext.getResources().getString(C0409fz.module_input_mode), this.mAppContext.getResources().getString(C0409fz.input_type), this.mInputType);
        }
    }

    @Override // com.sogou.common.InputInterface
    public void switchInputType(int i) {
        int i2 = this.mInputType;
        setInputType(i);
        int i3 = this.mInputType;
        if (i2 != i3) {
            loadIme(i3);
        }
    }

    public void updateIMELanguage(int i) {
        C0760qA.a(TAG, "updateIMELanguage  languageID:" + i);
        FG m310a = JF.a().m310a();
        DG a = m310a.a(i);
        if (a == null) {
            a = m310a.a();
        }
        getIMEStatusInfo().a(new GF(i, a.a(), a.m133b().get(0).a()));
    }

    @Override // com.sogou.common.InputInterface
    public void updateIMEStatus() {
        getIMEStatusInfo().b();
    }

    @Override // com.sogou.common.InputInterface
    public XF getComposingInfo() {
        return this.composingInfo;
    }

    @Override // com.sogou.common.InputInterface
    public int switchInputType() {
        if (this.mInputType == 0) {
            return this.mChInputType;
        }
        return 0;
    }

    public void initIMEStatus(String str) {
        int inputMode = getInputMode(str);
        if (inputMode != INPUT_MODE_NULL) {
            getIMEStatusInfo().a(new GF(GF.a(inputMode), GF.c(inputMode), GF.b(inputMode)));
        }
    }
}
